scriptName DSerArrowRemoval extends activemagiceffect

actor property PlayerRef auto
DSerDeadlyArrowsMonitor property MonitorScript auto
spell property BleedAbility auto
idle property IdleAnimation_Enter auto
idle property IdleAnimation_Exit auto
idle property IdleStop_Loose auto
Float property AnimWaitTime auto


;-- Variables ---------------------------------------
Float AttachedArrowAge


function OnEffectStart(actor Target, actor Caster)
	Bool WasInFirstPerson = false
	Bool WasHoldingWeapon = false
	
	AttachedArrowAge = game.GetGameSettingFloat("fAttachedArrowAgeMax")
	
	;Remove the bleed effect
	if PlayerRef.HasSpell(BleedAbility as form)
		PlayerRef.RemoveSpell(BleedAbility)
	endIf
	
	;
	if IdleAnimation_Enter != none
		;Force the camera into 3rd person
		if game.GetCameraState() == 0
			WasInFirstPerson = true
			game.ForceThirdPerson()
		endIf
		
		;If the player has a weapon out, it should be sheathed
		if PlayerRef.IsWeaponDrawn()
			WasHoldingWeapon = true
			PlayerRef.SheatheWeapon()
			;Wait until the weapon is sheathed to continue
			while PlayerRef.IsWeaponDrawn()
				utility.Wait(0.200000)
			endWhile
			utility.Wait(0.500000)
		endIf
		
		game.DisablePlayerControls(true, true, true, true, true, true, true, true, 0)
		
		;Play the Arrow Removal animation
		PlayerRef.PlayIdle(IdleAnimation_Enter)
	endIf
	
	utility.Wait(AnimWaitTime / 2 as Float)
	game.SetGameSettingFloat("fAttachedArrowAgeMax", 1.00000)
	
	Int numArrowsTotal = MonitorScript.numArrowsInYou
	Int numArrowsBroken = 0
	
	while MonitorScript.numArrowsInYou > 0
		MonitorScript.numArrowsInYou = MonitorScript.numArrowsInYou - 1
		if utility.RandomInt(0, 100) as Float <= 1.50000 * PlayerRef.GetAV("Marksman")
			PlayerRef.AddItem(MonitorScript.GetNthArrowInArrowArray(MonitorScript.numArrowsInYou), 1, false)
		else
			numArrowsBroken += 1
		endIf
		utility.Wait(1 as Float)
	endWhile
	
	if numArrowsTotal - numArrowsBroken > 1
		debug.notification((numArrowsTotal - numArrowsBroken) as String + "/" + numArrowsTotal as String + " arrows were recovered")
	elseIf numArrowsTotal - numArrowsBroken == 1
		debug.notification("One arrow was recovered")
	elseIf numArrowsTotal - numArrowsBroken == 0
		debug.notification("No arrows were recovered")
	endIf
	
	MonitorScript.EmptyTheArrowArray()
	
	utility.Wait(AnimWaitTime / 2 as Float)
	
	if IdleAnimation_Exit != none
		PlayerRef.PlayIdle(IdleAnimation_Exit)
		game.EnablePlayerControls(true, true, true, true, true, true, true, true, 0)
		if WasInFirstPerson
			game.ForceFirstPerson()
			utility.Wait(0.500000)
		endIf
		if WasHoldingWeapon
			PlayerRef.DrawWeapon()
		endIf
	else
		PlayerRef.PlayIdle(IdleStop_Loose)
		game.EnablePlayerControls(true, true, true, true, true, true, true, true, 0)
		if WasInFirstPerson
			game.ForceFirstPerson()
		endIf
		if WasHoldingWeapon
			utility.Wait(0.500000)
			PlayerRef.DrawWeapon()
		endIf
	endIf
	
	utility.Wait(2 as Float)
	
	if numArrowsTotal > 0
		debug.notification("Projectile wounds have been healed")
	endIf
	
	game.SetGameSettingFloat("fAttachedArrowAgeMax", AttachedArrowAge)
endFunction
