scriptName DSerNPCMonitor extends activemagiceffect

;-- Properties --------------------------------------
actor property PlayerRef auto

DSerDeadlyArrowsMonitor property DeadlyArrowsMonitor auto

spell property EnchantedArrow_RechargeSpell auto

globalvariable property MCM_ThrowArrows auto
globalvariable property MCM_ScalingWeight auto
globalvariable property MCM_EnchantArrows auto
globalvariable property MCM_ArrowWounds auto
globalvariable property Version_Global auto

armor property RingOfTheDragon auto
armor property RingOfAetherius auto
armor property RingOfTheWispmother auto
armor property RingOfTheWamasu auto

spell property EnchantArrow_IceDamage auto
spell property EnchantArrow_FireDamage auto
spell property EnchantArrow_MagicDamage auto
spell property EnchantArrow_ShockDamage auto

spell property EnchantedArrow_Type_Ice auto
spell property EnchantedArrow_Type_Fire auto
spell property EnchantedArrow_Type_Magic auto
spell property EnchantedArrow_Type_Shock auto

;faction property ActiveFollowerFaction auto
faction property WarlockFaction auto
race property DragonPriestRace auto
race property WispRace auto

keyword property EnchantedArrowRing auto
spell property EnchantedArrow_AmmoEquipped auto
spell property NPCMonitor auto
spell property BleedAbility auto

;-- Variables ---------------------------------------
actor TargetActor
Float Version = 1.3200



Event OnEffectStart(actor akTarget, actor akCaster)
	;Sets up the TargetActor variable
	TargetActor = akTarget
	
	;Handle female actors bow size
	if akTarget.GetEquippedWeapon(false)
		if akTarget.GetEquippedWeapon(false).GetWeaponType() == 7 && TargetActor.GetActorBase().GetSex() == 1
			netimmerse.SetNodeScale(TargetActor as objectreference, "SHIELD", 1.15000, false)
		endIf
	endIf
	
	;Register the NPC for bow release and reset events
	self.RegisterForAnimationEvent(PlayerRef as objectreference, "BowReset")
	self.RegisterForAnimationEvent(PlayerRef as objectreference, "BowRelease")
	
	if MCM_EnchantArrows.GetValueInt() == 1
		;Add rings to certain enemies
		if akTarget.GetRace() == DragonPriestRace
			;Checks for Dragon Priests
			if utility.RandomInt(1, 100) <= 100
				akTarget.AddItem(RingOfTheDragon as form, 1, true)
				debug.trace("[AGO] Ring of the Dragon added to " + akTarget as String, 0)
				;debug.notification("[AGO] Ring of the Dragon added to " + akTarget as String)
			endIf
		elseIf akTarget.GetRace() == WispRace
			;Checks for Wispmothers
			if utility.RandomInt(1, 100) <= 100
				akTarget.AddItem(RingOfTheWispmother as form, 1, true)
				debug.trace("[AGO] Ring of the Wispmother added to " + akTarget as String, 0)
				;debug.notification("[AGO] Ring of the Wispmother added to " + akTarget as String)
			endIf
		elseIf akTarget.IsInFaction(WarlockFaction)
			;Checks for Mages
			if utility.RandomInt(1, 100) <= 10
				;10% Chance to add Ring of Aetherius
				akTarget.AddItem(RingOfAetherius as form, 1, true)
				debug.trace("[AGO] Ring of Aetherius added to " + akTarget as String, 0)
			elseIf utility.RandomInt(1, 100) <= 10
				;10% Chance to add Ring of the Wamasu
				akTarget.AddItem(RingOfTheWamasu as form, 1, true)
				debug.trace("[AGO] Ring of the Wamasu added to " + akTarget as String, 0)
			endIf
		endIf
	endIf
endEvent

;Handle female actors bow size  and ammo monitor
Event OnObjectEquipped(form akBaseObject, objectreference akReference)
	;Wait for any Unequip events to finish
	utility.WaitMenuMode(0.300000)
	if akBaseObject as weapon
		if (akBaseObject as weapon).GetWeaponType() == 7
			if TargetActor.GetActorBase().GetSex() == 1
				netimmerse.SetNodeScale(TargetActor as objectreference, "SHIELD", 1.15000, false)
			endIf
		endIf
	elseIf akBaseObject as ammo
		if !TargetActor.HasSpell(EnchantedArrow_AmmoEquipped as form)
			TargetActor.AddSpell(EnchantedArrow_AmmoEquipped)
		endIf
	endIf
endEvent

;Handle female actors bow size and ammo monitor
Event OnObjectUnequipped(form akBaseObject, objectreference akReference)
	if akBaseObject as weapon
		if (akBaseObject as weapon).GetWeaponType() == 7 && TargetActor.GetActorBase().GetSex() == 1
			netimmerse.SetNodeScale(TargetActor as objectreference, "SHIELD", 1.00000, false)
		endIf
	elseIf akBaseObject as ammo
		if TargetActor.HasSpell(EnchantedArrow_AmmoEquipped as form)
			TargetActor.RemoveSpell(EnchantedArrow_AmmoEquipped)
		endIf
	endIf
endEvent

Event OnDying(actor akKiller)
	if TargetActor.HasSpell(BleedAbility as form)
		TargetActor.RemoveSpell(BleedAbility)
	endIf
endEvent

Event OnDeath(actor akKiller)
	TargetActor.RemoveSpell(NPCMonitor)
endEvent

function RemoveNPCMonitors()
	TargetActor.RemoveSpell(NPCMonitor)
endFunction

Event OnHit(objectreference akAggressor, form akSource, Projectile akProjectile, Bool abPowerAttack, Bool abSneakAttack, Bool abBashAttack, Bool abHitBlocked)

	if akSource as weapon
		if Version != Version_Global.GetValue()
			Version = Version_Global.GetValue()
			debug.trace("[DSerAGO] NPC Monitor on " + TargetActor as String + " updated to version " + Version as String, 0)
			self.RemoveNPCMonitors()
			return
		endIf
		
		;Get the aggressor's right hand weapon
		weapon AggressorWeapon = (akAggressor as actor).GetEquippedWeapon(false)
		
		;Only progress if the weapon is a bow
		if AggressorWeapon == none || AggressorWeapon.GetWeaponType() != 7
			return 
		endIf
		
		if (akSource as weapon).GetWeaponType() == 7 && abBashAttack == false && abHitBlocked == false
			;Hit was an arrow, trigger the bleed effect
			if MCM_ArrowWounds.GetValueInt() == 1
				debug.trace("TargetActor as objectreference = " + TargetActor as objectreference)
				debug.trace("akAggressor = " + akAggressor)
				BleedAbility.Cast(akAggressor, TargetActor as objectreference)
			endIf
			
			if MCM_EnchantArrows.GetValueInt() == 1
				if (akAggressor as actor).HasSpell(EnchantedArrow_Type_Fire as form)
					EnchantArrow_FireDamage.SetNthEffectMagnitude(0, ((MCM_ScalingWeight.GetValue() * ((akAggressor as actor).GetAV("Enchanting") as Int) as Float) as Int) as Float)
					EnchantArrow_FireDamage.Cast(akAggressor, TargetActor as objectreference)
					debug.trace("[DSerAGO] Fire damage applied to " + TargetActor as objectreference)
					if akAggressor.HasEffectKeyword(EnchantedArrowRing) == 0 as Bool
						(akAggressor as actor).RemoveSpell(EnchantedArrow_Type_Fire)
					endIf
				elseIf (akAggressor as actor).HasSpell(EnchantedArrow_Type_Ice as form)
					EnchantArrow_IceDamage.SetNthEffectMagnitude(0, ((MCM_ScalingWeight.GetValue() * ((akAggressor as actor).GetAV("Enchanting") as Int) as Float) as Int) as Float)
					EnchantArrow_IceDamage.Cast(akAggressor, TargetActor as objectreference)
					debug.trace("[DSerAGO] Ice damage applied to " + TargetActor as objectreference)
					if akAggressor.HasEffectKeyword(EnchantedArrowRing) == 0 as Bool
						(akAggressor as actor).RemoveSpell(EnchantedArrow_Type_Ice)
					endIf
				elseIf (akAggressor as actor).HasSpell(EnchantedArrow_Type_Magic as form)
					EnchantArrow_MagicDamage.SetNthEffectMagnitude(0, ((MCM_ScalingWeight.GetValue() * ((akAggressor as actor).GetAV("Enchanting") as Int) as Float) as Int) as Float)
					EnchantArrow_MagicDamage.Cast(akAggressor, TargetActor as objectreference)
					debug.trace("[DSerAGO] Magic damage applied to " + TargetActor as objectreference)
					if akAggressor.HasEffectKeyword(EnchantedArrowRing) == 0 as Bool
						(akAggressor as actor).RemoveSpell(EnchantedArrow_Type_Magic)
					endIf
				elseIf (akAggressor as actor).HasSpell(EnchantedArrow_Type_Shock as form)
					EnchantArrow_ShockDamage.SetNthEffectMagnitude(0, ((MCM_ScalingWeight.GetValue() * ((akAggressor as actor).GetAV("Enchanting") as Int) as Float) as Int) as Float)
					EnchantArrow_ShockDamage.Cast(akAggressor, TargetActor as objectreference)
					debug.trace("[DSerAGO] Shock damage applied to " + TargetActor as objectreference)
					if akAggressor.HasEffectKeyword(EnchantedArrowRing) == 0 as Bool
						(akAggressor as actor).RemoveSpell(EnchantedArrow_Type_Shock)
					endIf
				endIf
			endIf
		elseIf AggressorWeapon.GetWeaponType() == 7 && abBashAttack == true
			;Hit was a bash, trigger a stab/throw depending on Throw Arrows setting
			if akSource == PlayerRef as form && MCM_ThrowArrows.GetValueInt() == 1
				return 
			else
				AggressorWeapon.Fire(akAggressor, none)
			endIf
		endIf
	endIf
endEvent

Event OnAnimationEvent(objectreference akSource, String asEventName)
	if akSource == TargetActor as objectreference
		if asEventName == "BowRelease"
			if akSource.HasEffectKeyword(EnchantedArrowRing) == 1 as Bool
				EnchantedArrow_RechargeSpell.Cast(akSource, akSource)
			endIf
		elseIf asEventName == "BowReset"
			DeadlyArrowsMonitor.ResetArrowFX(TargetActor)
		endIf
	endIf
endEvent

